aboutsummaryrefslogtreecommitdiff
path: root/src/google/minidump_processor.h
diff options
context:
space:
mode:
authormmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2006-10-20 01:46:38 +0000
committermmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2006-10-20 01:46:38 +0000
commit246f4068280b5b191303ff13671e43a0522987de (patch)
tree9de2b66c7d8f0241de53669de045318d6283da7e /src/google/minidump_processor.h
parentImprovements for Windows client/tool-side code. r=bryner (diff)
downloadbreakpad-246f4068280b5b191303ff13671e43a0522987de.tar.xz
Handle frame pointer omission, (#21), part 4 (final part!): FPO stackwalker.
r=bryner - This change allows Airbag to properly walk win32 stacks produced by code built with MSVC's frame pointer omission optimization (/Oy). This optimization is enabled at /O1 and /O2. - There too many interface and file format changes to list here. http://groups.google.com/group/airbag-dev/browse_thread/thread/85ce85bfa8457ece git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@42 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/google/minidump_processor.h')
-rw-r--r--src/google/minidump_processor.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/google/minidump_processor.h b/src/google/minidump_processor.h
index d5470b70..925ea90a 100644
--- a/src/google/minidump_processor.h
+++ b/src/google/minidump_processor.h
@@ -31,12 +31,12 @@
#define GOOGLE_MINIDUMP_PROCESSOR_H__
#include <string>
-#include "google/stack_frame.h"
namespace google_airbag {
using std::string;
+class CallStack;
class SymbolSupplier;
class MinidumpProcessor {
@@ -46,9 +46,9 @@ class MinidumpProcessor {
MinidumpProcessor(SymbolSupplier *supplier);
~MinidumpProcessor();
- // Fills in the given StackFrames vector by processing the minidump file.
- // Returns true on success.
- bool Process(const string &minidump_file, StackFrames *stack_frames);
+ // Fills in the given CallStack by processing the minidump file. Returns
+ // true on success.
+ bool Process(const string &minidump_file, CallStack *stack);
private:
SymbolSupplier *supplier_;